aboutsummaryrefslogtreecommitdiff
path: root/src-qt5/core/lumina-desktop-unified/src-WM
diff options
context:
space:
mode:
authorKen Moore <ken@ixsystems.com>2017-01-05 16:53:18 -0500
committerKen Moore <ken@ixsystems.com>2017-01-05 16:53:18 -0500
commit837a2c7e9618fe31bde83f18e662ba257a40b702 (patch)
tree8c922e633f12477063a260e73f87c47c2e131af3 /src-qt5/core/lumina-desktop-unified/src-WM
parentFix up the appearance of the Git menu when opening new tabs. (diff)
downloadlumina-837a2c7e9618fe31bde83f18e662ba257a40b702.tar.gz
lumina-837a2c7e9618fe31bde83f18e662ba257a40b702.tar.bz2
lumina-837a2c7e9618fe31bde83f18e662ba257a40b702.zip
Get some more stuff merged over. Starting to glue the various global structures together.
Diffstat (limited to 'src-qt5/core/lumina-desktop-unified/src-WM')
-rw-r--r--src-qt5/core/lumina-desktop-unified/src-WM/LXcbEventFilter.cpp24
1 files changed, 10 insertions, 14 deletions
diff --git a/src-qt5/core/lumina-desktop-unified/src-WM/LXcbEventFilter.cpp b/src-qt5/core/lumina-desktop-unified/src-WM/LXcbEventFilter.cpp
index abbe5a5a..0a7ca536 100644
--- a/src-qt5/core/lumina-desktop-unified/src-WM/LXcbEventFilter.cpp
+++ b/src-qt5/core/lumina-desktop-unified/src-WM/LXcbEventFilter.cpp
@@ -1,6 +1,6 @@
//===========================================
-// Lumina-DE source code
-// Copyright (c) 2015, Ken Moore
+// Lumina-desktop source code
+// Copyright (c) 2015-2017, Ken Moore
// Available under the 3-clause BSD license
// See the LICENSE file for full details
//===========================================
@@ -8,15 +8,11 @@
//==================================================
// NOTE: All the XCB interactions and atoms are accessed via:
// LWM::SYSTEM->EWMH.(atom name)
// LWM::SYSTEM->(do something)
// (LWM::SYSTEM is the global XCB structure)
//==================================================
-
-#include <LuminaX11.h>
-#include <QDebug>
-
-//#include <xcb/screensaver.h>
+#include "global-objects.h"
#define DEBUG 1
// Also keep the root window/screen around for use in the filters
@@ -38,14 +34,14 @@ void EventFilter::start(){
if(DEBUG){ qDebug() << " - Install event filter..."; }
QCoreApplication::instance()->installNativeEventFilter(EF);
if(DEBUG){ qDebug() << " - Run request check..."; }
- if(!LWM::SYSTEM->setupEventsForRoot()){
+ if(!Lumina::SYSTEM->setupEventsForRoot()){
qCritical() << "[ERROR] Unable to setup WM event retrieval. Is another WM running?";
exit(1);
}
if(DEBUG){ qDebug() << " - Create WM ID Window"; }
- WMFlag = LWM::SYSTEM->WM_CreateWindow();
- LWM::SYSTEM->setupEventsForRoot(WMFlag);
- LWM::SYSTEM->WM_Set_Supporting_WM(WMFlag);
+ WMFlag = Lumina::SYSTEM->WM_CreateWindow();
+ Lumina::SYSTEM->setupEventsForRoot(WMFlag);
+ Lumina::SYSTEM->WM_Set_Supporting_WM(WMFlag);
QCoreApplication::instance()->flush();
}
bgstack15
@@ -8,15 +8,11 @@
//==================================================
// NOTE: All the XCB interactions and atoms are accessed via:
-// LWM::SYSTEM->EWMH.(atom name)
-// LWM::SYSTEM->(do something)
-// (LWM::SYSTEM is the global XCB structure)
+// Lumina::SYSTEM->EWMH.(atom name)
+// Lumina::SYSTEM->(do something)
+// (Lumina::SYSTEM is the global XCB structure)
//==================================================